@@ -1,5 +1,5 @@
 package Clang::Cursor;
-$Clang::Cursor::VERSION = '0.07';
+$Clang::Cursor::VERSION = '0.08';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Clang::Cursor - Clang cursor class
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -41,9 +41,16 @@ C<Clang::Cursor> objects too.
 
 =head2 location( )
 
-Retrieve the location of the given cursor. This function returns three values,
-a string containing the source file name, an integer containing the line number
-and another integer containing the column number.
+Retrieve the location of the given cursor. This function returns five values: a
+string containing the source file name, an integer containing the initial line
+number, an integer containing the initial column number, an integer containing
+the final line number, and another integer containing the final column number.
+
+=head2 access_specifier( )
+
+Retrieve the access of the given cursor. This can return the following values:
+C<invalid>, C<public>, C<protected> or C<private>. Note that this only works
+for C++ code, it will return C<invalid> for C functions.
 
 =head1 AUTHOR
 
